@@ -45,9 +45,15 @@ class HttpServer(Worker):
         self.sanic_app.after_server_stop(self.close)
         self.sanic_app.ctx.channel = self.channel
         self.rt_connections = []
+        self._set_sanic_confs()
         if self.router and issubclass(self.router.__class__, ExtRouter):
             self.router.apply_routes(self.sanic_app)
 
+    def _set_sanic_confs(self):
+        self.sanic_app.config.SWAGGER_UI_CONFIGURATION = {
+            "docExpansion": 'none'
+        }
+
     async def _run(self):
         await self._init_resources()
         # noinspection PyAsyncCall
